@@ -19,13 +19,9 @@ import (
 
 	"github.com/spf13/pflag"
 
-	// Import all Kubernetes client auth plugins (e.g. Azure, GCP, OIDC, etc.)
-	_ "k8s.io/client-go/plugin/pkg/client/auth"
-	"sigs.k8s.io/controller-runtime/pkg/manager/signals"
-
 	"k8s.io/klog"
 
-	"github.com/open-cluster-management/multicloud-operators-deployable/cmd/manager/exec"
+	"github.com/stolostron/multicloud-operators-deployable/cmd/manager/exec"
 )
 
 func main() {
@@ -40,5 +36,5 @@ func main() {
 
 	pflag.Parse()
 
-	exec.RunManager(signals.SetupSignalHandler())
+	exec.RunManager()
 }
